hotspot/src/share/vm/gc_implementation/g1/concurrentG1Refine.hpp
changeset 17854 d65bc1546091
parent 17327 4bd0581aa231
child 23855 c4574075402c
--- a/hotspot/src/share/vm/gc_implementation/g1/concurrentG1Refine.hpp	Sat Jun 01 10:00:56 2013 +0200
+++ b/hotspot/src/share/vm/gc_implementation/g1/concurrentG1Refine.hpp	Tue May 28 09:32:06 2013 +0200
@@ -35,6 +35,7 @@
 class G1CollectedHeap;
 class G1HotCardCache;
 class G1RemSet;
+class DirtyCardQueue;
 
 class ConcurrentG1Refine: public CHeapObj<mtGC> {
   ConcurrentG1RefineThread** _threads;
@@ -78,9 +79,15 @@
 
   void reinitialize_threads();
 
   // Iterate over the conc refine threads
   void threads_do(ThreadClosure *tc);
 
+  // Iterate over all worker refinement threads
+  void worker_threads_do(ThreadClosure * tc);
+
+  // The RS sampling thread
+  ConcurrentG1RefineThread * sampling_thread() const;
+
   static int thread_num();
 
   void print_worker_threads_on(outputStream* st) const;
@@ -78,9 +79,15 @@
   void reinitialize_threads();
 
-  // Iterate over the conc refine threads
+  // Iterate over all concurrent refinement threads
   void threads_do(ThreadClosure *tc);
 